// Variables
// --------------------------

@sf-font-path:        "../fonts";
@sf-css-prefix:       sf;
@sf-version:          "1.0.0";
@sf-border-color:     #eee;
@sf-inverse:          #fff;
@sf-li-width:         (30em / 14);

@sf-var-digit: "A";
@sf-var-magic-btn: "B";
@sf-var-sipstation-banner: "C";
@sf-var-sipstation-logo: "D";
@sf-var-endpoint-banner: "E";
@sf-var-cos-logo: "F";
@sf-var-ha-logo: "G";
@sf-var-otts-logo: "H";
@sf-var-qxact-logo: "I";
@sf-var-tango-cartoon: "J";
@sf-var-qxact-dialer-logo: "K";
@sf-var-qxact-fax-logo: "L";
@sf-var-community-banner: "a";
@sf-var-freepbx-distro-logo: "b";
@sf-var-call-center-builder-logo: "c";
@sf-var-freepbx-world-logo: "d";
@sf-var-freepbx-hosting-banner: "e";
@sf-var-tango-logo: "f";
@sf-var-tango-tagline-logo: "g";
@sf-var-pomps-tagline-logo: "h";
@sf-var-issues: "i";
@sf-var-portal-logo: "j";
@sf-var-phone-apps-logo: "k";
@sf-var-linux101-logo: "l";
@sf-var-m3-logo: "m";
@sf-var-pbxtended-logo: "n";
@sf-var-pomps-logo: "o";
@sf-var-pbxact-logo: "p";
@sf-var-portal-banner: "q";
@sf-var-pencil: "r";
@sf-var-schmooze-tagline-logo: "t";
@sf-var-schmooze-logo: "t";
@sf-var-support-logo: "u";
@sf-var-system-builder-logo: "v";
@sf-var-wiki-logo: "w";
@sf-var-pro-voice-recordings-logo: "x";
@sf-var-xact-view-logo: "y";
@sf-var-xmpp-logo: "z";
