Hello %fname%,

We have received new password request for your account (%username%).
If this request was initiated by you, please click on following link and change your password:
%link%

This request is valid until %valid%

Thanks,
The %brand% Team
