{
  // Default options
  'functions': true
}

.emojione {
  text-indent: -9999em;
  image-rendering: optimizeQuality;
  font-size: inherit;
  height: 64px;
  width: 64px;
  top: -3px;
  position: relative;
  display: inline-block;
  margin: 0 .15em;
  line-height: normal;
  vertical-align: middle;
  background-image: url('emojione.sprites.png');
  background-repeat: no-repeat;
}

{{#items}}
.{{name}} {
  background-position: {{px.offset_x}} {{px.offset_y}};
}
{{/items}}
