/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */

.@{sf-css-prefix}-community-banner:before { content: @sf-var-community-banner; }
.@{sf-css-prefix}-digit:before { content: @sf-var-digit; }
.@{sf-css-prefix}-magic-btn:before { content: @sf-var-magic-btn; }
.@{sf-css-prefix}-schmooze-logo:before { content: @sf-var-schmooze-logo; }
.@{sf-css-prefix}-endpoint-banner:before { content: @sf-var-endpoint-banner; }
.@{sf-css-prefix}-cos-logo:before { content: @sf-var-cos-logo; }
.@{sf-css-prefix}-ha-logo:before { content: @sf-var-ha-logo; }
.@{sf-css-prefix}-otts-logo:before { content: @sf-var-otts-logo; }
.@{sf-css-prefix}-qxact-logo:before { content: @sf-var-qxact-logo; }
.@{sf-css-prefix}-tango-cartoon:before { content: @sf-var-tango-cartoon; }
.@{sf-css-prefix}-qxact-dialer-logo:before { content: @sf-var-qxact-dialer-logo; }
.@{sf-css-prefix}-qxact-fax-logo:before { content: @sf-var-qxact-fax-logo; }
.@{sf-css-prefix}-community-banner:before { content: @sf-var-community-banner; }
.@{sf-css-prefix}-freepbx-distro-logo:before { content: @sf-var-freepbx-distro-logo; }
.@{sf-css-prefix}-call-center-builder-logo:before { content: @sf-var-call-center-builder-logo; }
.@{sf-css-prefix}-freepbx-world-logo:before { content: @sf-var-freepbx-world-logo; }
.@{sf-css-prefix}-freepbx-hosting-banner:before { content: @sf-var-freepbx-hosting-banner; }
.@{sf-css-prefix}-tango-logo:before { content: @sf-var-tango-logo; }
.@{sf-css-prefix}-tango-tagline-logo:before { content: @sf-var-tango-tagline-logo; }
.@{sf-css-prefix}-pomps-tagline-logo:before { content: @sf-var-pomps-tagline-logo; }
.@{sf-css-prefix}-issues:before { content: @sf-var-issues; }
.@{sf-css-prefix}-portal-logo:before { content: @sf-var-portal-logo; }
.@{sf-css-prefix}-phone-apps-logo:before { content: @sf-var-phone-apps-logo; }
.@{sf-css-prefix}-linux101-logo:before { content: @sf-var-linux101-logo; }
.@{sf-css-prefix}-m3-logo:before { content: @sf-var-m3-logo; }
.@{sf-css-prefix}-pbxtended-logo:before { content: @sf-var-pbxtended-logo; }
.@{sf-css-prefix}-pomps-logo:before { content: @sf-var-pomps-logo; }
.@{sf-css-prefix}-pbxact-logo:before { content: @sf-var-pbxact-logo; }
.@{sf-css-prefix}-portal-banner:before { content: @sf-var-portal-banner; }
.@{sf-css-prefix}-pencil:before { content: @sf-var-pencil; }
.@{sf-css-prefix}-schmooze-tagline-logo:before { content: @sf-var-schmooze-tagline-logo; }
.@{sf-css-prefix}-schmooze-logo:before { content: @sf-var-schmooze-logo; }
.@{sf-css-prefix}-support-logo:before { content: @sf-var-support-logo; }
.@{sf-css-prefix}-system-builder-logo:before { content: @sf-var-system-builder-logo; }
.@{sf-css-prefix}-wiki-logo:before { content: @sf-var-wiki-logo; }
.@{sf-css-prefix}-pro-voice-recordings-logo:before { content: @sf-var-pro-voice-recordings-logo; }
.@{sf-css-prefix}-xact-view-logo:before { content: @sf-var-xact-view-logo; }
.@{sf-css-prefix}-xmpp-logo:before { content: @sf-var-xmpp-logo; }
