#module-page-settings {
	.settings {
		background-color: aliceblue;
		border-radius: 10px;
		.title {
			padding: 5px;
			font-weight: bold;
			text-align: center;
			background-color: whitesmoke;
			border-top-left-radius: 5px;
			border-top-right-radius: 5px;
		}
		.content {
			padding: 10px;
		}
	}
	.section {
		margin-bottom: 10px;
		width: 33.3%
	}
}
