/* FONTS */
@font-face {
	font-family: 'cinzel';
	src: url('assets/fonts/cinzel-regular-webfont.eot');
	src: url('assets/fonts/cinzel-regular-webfont.eot?#iefix') format('embedded-opentype'),
		url('assets/fonts/cinzel-regular-webfont.woff') format('woff'),
		url('assets/fonts/cinzel-regular-webfont.ttf') format('truetype'),
		url('assets/fonts/cinzel-regular-webfont.svg#cinzelregular') format('svg');
	font-weight: normal;
	font-style: normal;
}

@font-face {
	font-family: 'cinzel';
	src: url('assets/fonts/cinzel-bold-webfont.eot');
	src: url('assets/fonts/cinzel-bold-webfont.eot?#iefix') format('embedded-opentype'),
		url('assets/fonts/cinzel-bold-webfont.woff') format('woff'),
		url('assets/fonts/cinzel-bold-webfont.ttf') format('truetype'),
		url('assets/fonts/cinzel-bold-webfont.svg#cinzelbold') format('svg');
	font-weight: bold;
	font-style: normal;
}

@font-face {
	font-family: 'lato';
	src: url('assets/fonts/lato-regular-webfont.eot');
	src: url('assets/fonts/lato-regular-webfont.eot?#iefix') format('embedded-opentype'),
		url('assets/fonts/lato-regular-webfont.woff') format('woff'),
		url('assets/fonts/lato-regular-webfont.woff2') format('woff2'),
		url('assets/fonts/lato-regular-webfont.ttf') format('truetype'),
		url('assets/fonts/lato-regular-webfont.svg#latoregular') format('svg');
	font-weight: normal;
	font-style: normal;
}

@font-face {
	font-family: 'lato';
	src: url('assets/fonts/lato-bold-webfont.eot');
	src: url('assets/fonts/lato-bold-webfont.eot?#iefix') format('embedded-opentype'),
		url('assets/fonts/lato-bold-webfont.woff') format('woff'),
		url('assets/fonts/lato-bold-webfont.woff2') format('woff2'),
		url('assets/fonts/lato-bold-webfont.ttf') format('truetype'),
		url('assets/fonts/lato-bold-webfont.svg#latobold') format('svg');
	font-weight: bold;
	font-style: normal;
}

/* Make all input boxes have a font where you can tell the difference between upper and lower case fonts */
input, textarea {
	font-family: 'lato', sans-serif;
}

/* MIXINS */
.border-radius (@radius: 5px) {
	-webkit-border-radius: @radius;
	-moz-border-radius: @radius;
	border-radius: @radius;
}

/* GLOBAL DISPLAY */
html, #content-container{
	height: 100%;
}

body {
	font-family: 'lato', sans-serif;
	height: 100%;
	margin: 0;
	background-repeat: no-repeat;
	background-attachment: fixed;
	/* IE9 SVG, needs conditional override of 'filter' to 'none' */
	background: -moz-linear-gradient(top, rgba(220,236,254,1) 0%, rgba(220,236,254,0.51) 50%, rgba(220,236,254,0.5) 51%, rgba(220,236,254,1) 100%);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(220,236,254,1)), color-stop(50%,rgba(220,236,254,0.51)), color-stop(51%,rgba(220,236,254,0.5)), color-stop(100%,rgba(220,236,254,1)));
  background: -webkit-linear-gradient(top, rgba(220,236,254,1) 0%,rgba(220,236,254,0.51) 50%,rgba(220,236,254,0.5) 51%,rgba(220,236,254,1) 100%);
  background: -o-linear-gradient(top, rgba(220,236,254,1) 0%,rgba(220,236,254,0.51) 50%,rgba(220,236,254,0.5) 51%,rgba(220,236,254,1) 100%);
  background: -ms-linear-gradient(top, rgba(220,236,254,1) 0%,rgba(220,236,254,0.51) 50%,rgba(220,236,254,0.5) 51%,rgba(220,236,254,1) 100%);
  background: linear-gradient(to bottom, rgba(220,236,254,1) 0%,rgba(220,236,254,0.51) 50%,rgba(220,236,254,0.5) 51%,rgba(220,236,254,1) 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#dcecfe', endColorstr='#dcecfe',GradientType=0 );
}

h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6 {
	font-family: 'lato', sans-serif;
	margin-top: 2px;
	margin-bottom: 10px;
}



#content-container{
	@media only screen and (min-width : 768px) {
		display: table;
		vertical-align: middle;
	}
}

#content-container .vertical-center-row{
	@media only screen and (min-width : 768px) {
		display: table-cell;
		vertical-align: middle;
	}
}

.input-margin {
	margin-top:5px;
	margin-bottom:5px;
}

/* LOGIN */
#login-window {
	padding-top: 20px;
	@media only screen and (min-width : 768px) {
		width: 30%;
		padding-left: 15px;
		padding-right: 15px;
		padding-top: 10px;
 	}
	@media only screen and (max-width : 767px) {
		padding: 10px;
		padding-top: 20px;
	}
	@media only screen and (min-width : 974px) {
		padding-top: 20px;
 	}
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	margin: auto;
	height: 250px;
	.border-radius(20px);
	box-shadow: 0px 0px 10px 3px rgba(119, 119, 119, 0.75);
	-moz-box-shadow: 0px 0px 10px 3px rgba(119, 119, 119, 0.75);
	-webkit-box-shadow: 0px 0px 10px 3px rgba(119, 119, 119, 0.75);
	background-color: #dcecfe;
	overflow: hidden;

	.header {
		font-size: x-large;
	}

	.extras {
		width: 100%;
	}

	.action-switch {
		td {
			text-align: center;
			span {
				cursor: pointer;
			}
			span:hover {
				color: rgb(51, 97, 171);
			}
		}
		height: 30px;
		vertical-align: top;
	}

	.lshow {
	}

	.reset-title {
		text-align: center;
		font-size: larger;
	}

	.remember-me {
		.text {
			width:30%;
			white-space:nowrap;
			text-align: right;
			padding-right: 7px;
			vertical-align: top;
			font-size: larger;
		}

		.checkbox-c {
			width:30%;
			text-align: left;
		}
	}

	.lhide {
		display: none;
	}

	.button-row {
		width:100%;
		text-align: center;
	}
}

/* LOGGED IN CONTENT DISPLAY */
/* BREADCRUMB/MENU/LOGOUT BAR */
#nav-bar-background {
	width: 100%;
	background-color: #f5f5f5;
	height: 36px;
	margin-bottom: 20px;
	position: relative;
	z-index:400;
	.breadcrumb {
		background-color: transparent;
	}
	#global-message-container {
		position: absolute;
		margin: auto;
		background-color: rgb(247, 106, 106);
		height: 36px;
		width: 100%;
		z-index: 50;
		display: none;
		#global-message {
			text-align:center;
			position: absolute;
			top: 25%;
			left: 0;
			right: 0;
			font-style: italic;
			font-weight: bold;
		}
	}
	#bc-mobile-icon {
		@media only screen and (min-width : 768px) {
			display: none;
		}
		cursor: pointer;
		width: 33px;
		text-align: center;
		font-size: x-large;
		padding-left: 10px;
		left: 0;
		position: absolute;
		z-index: 50;
	}

	#top-dashboard-nav {
		position: absolute;
		z-index: 50;
		@media only screen and (max-width : 767px) {
			left: 30px;
		}
		.home {
			@media only screen and (max-width : 767px) {
				display: none;
			}
		}
		.module:before{
			@media only screen and (max-width : 767px) {
				display: none;
			}
		}
		.module {
			@media only screen and (max-width : 540px) {
				display: none;
			}
		}
		.subsection:before{
			@media only screen and (max-width : 540px) {
				display: none;
			}
		}
		.subsection {
			@media only screen and (max-width : 300px) {
				display: none;
			}
		}
	}

	#top-dashboard-nav-right {
		top: 5px;
		cursor: pointer;
		position: absolute;
		right: 0;
		z-index: 50;
		font-size: 120%;
		height: 100%;
		.nav-btns {
			top: 0;
			height: 36px;
			margin-top: -6px;
			position: relative;
			float: left;
			.module-container {
				float: left;
				height: 36px;
				padding: 5px;
				position: relative;
				z-index: 5;
				width: 33px;
				.icon {
					height: 32px;
					width: 40px;
					overflow: hidden;
					i {
						font-size: 150%;
						color: black;
						opacity: .6;
						transition: opacity .5s;
						padding: 0.5px;
						width: 23px;
					}
					.out {
						opacity: 0;
					}
					.badge {
						min-width: 18px;
						padding: 2px 4px;
						font-size: 13px;
						background-color: #BB0000;
						position: relative;
						margin-top: -15px;
						margin-left: 7px;
						transition: color .5s ease-in;
						top: -21px;
						right: -1px;
					}
				}
				#settings-btn {
					margin-top: 1px;
				}
			}
			.module-container:hover > .icon > i, .module-container.active > .icon > i {
				opacity: 1;
			}
			.module-container:hover > .icon > .badge, .module-container.active > .icon > .badge {
				background-color: rgb(219, 0, 0);
			}
		}
	}
}

.nav-btn-menu {
	position: absolute;
	font-size: 95%;
	right: 0;
	z-index: 399;
	list-style: none;
	text-align: right;
	min-width: 90px;
	/* max-width: 193px; */
	padding: 0;
	background-color: #f5f5f5;
	border-left: 1px solid #cccccc;
	border-bottom: 1px solid #cccccc;
	border-bottom-left-radius: 4px;
	-webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
	box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
	background-clip: padding-box;
	display: none;
	overflow: hidden;
	transition: top .5s;
	a {
		display:block;
		color: #262626;
		padding: 5px;
		cursor: pointer;
	}
	> li > a:hover, > li > a:focus {
		text-decoration: none;
		color: #262626;
		background-color: #ffffff;
	}
	li hr {
		margin-top: 2px;
		margin-bottom: 2px;
	}
}

.clear {
	clear: both;
}

/* FULL SCREEN NAV */
#fs-navside {
	font-size: 15px;
	@media only screen and (max-width : 767px) {
		display: none;
	}
	.nav > li > a {
		padding: 5px 10px
	}
	.dropdown-menu {
		padding: 1px 0;
		max-height: 136px;
		overflow-y: auto;
	}
}

/* DASHBOARD CONTENT */

.dashboard-container {
	background-color: #dcecfe;
	overflow: hidden;
	background-image: url("assets/images/noise.png");
}

/*This Adjusts the whole shebang, the whole container */
.center-box {
	width: 100%;
	height: 100%;
	position: absolute;
	top:0;
	bottom: 0;
	left: 0;
	right: 0;
	margin: auto;
}

#container-fixed-left {
	margin-left: 0px;
}

#dashboard-content {
	overflow-y: auto;
	overflow-x: hidden;
	transition: height 0.1s ease;
}

/* JQUERYUI OVERRIDES */
.buttonset {
	background: linear-gradient(center top , #6b85b3, #334d86);
	background:-moz-linear-gradient(center top , #6b85b3, #334d86);
	background: -webkit-gradient(linear, center top, center bottom, from(#6b85b3), to(#334d86));
	height: 16px;
	padding: 10px 20px 20px;
}

section.content {
	font-family: 'lato', sans-serif;
	padding: 10px 20px;
}

#loader-screen {
	width: 100%;
	height: 100%;
	top: 0px;
	left: 0px;
	position: absolute;
	opacity: 0.7;
	background-color: #FFF;
	z-index: 99;
	text-align: center;
	display: none;
}

#loader-screen-content {
	margin: auto;
	position: absolute;
	top: 50%;
	left: 0;
	bottom: 0;
	right: 0;
	font-size: 150%;
}

#footer {
	background-color: #f5f5f5;
	overflow: hidden;
	position: absolute;
	width: 100%;
	height: 79px;
	bottom: 0;
	transition: bottom .3s;
	z-index: 400;
}
#footer.shrink {
	bottom: -75px;
}

#footer-bar {
	height: 4px;
	background-color: #DDDDDD;
}

#footer-content {
	font-size: 75%;
	color: black;
	font-family: 'lato', sans-serif;
	text-align: center;
	height: 100%;
	padding-top: 2px;
}
#footer-image {
	display: inline-block;
	vertical-align: bottom;
	padding-top: 2px;
}
#footer-message {
	display: inline-block;
	@media only screen and (max-width : 460px) {
		text-align: left;
	}
}
#footer-message .small-text {
	font-size: 90%;
}
#footer-message a, #footer-message a:active, #footer-message a:focus {
	color:black;
	text-decoration:none;
}
#footer-message a:hover {
	color:lightgrey;
}

.alert {
	padding: 5px;
}

.dialog {
	background-color: #FFFFFF;
	position: fixed;
	z-index: 5000;
	top: 50%;
	left: 50%;
	border: 1px solid rgb(202, 202, 202);
	border-radius: 5px;
	margin-top: -75px;
	margin-left: -125px;
	height: 150px;
	width: 250px;
	-webkit-box-shadow: 10px 10px 19px -1px rgba(0,0,0,0.75);
	-moz-box-shadow: 10px 10px 19px -1px rgba(0,0,0,0.75);
	box-shadow: 10px 10px 19px -1px rgba(0,0,0,0.75);
	.title {
		padding: 6px;
		border-top-left-radius: 5px;
		border-top-right-radius: 5px;
		font-weight: bold;
		background-color: whitesmoke;
		font-size: 110%;
		.fa-times {
			float: right;
			padding: 2px;
			margin-right: 3px;
			cursor: pointer;
			font-weight: normal;
		}
	}
	.content {
		padding: 5px;
	}
}
.form-group {
    label.help {
        cursor: help;
    }
    .help-block.help-hidden {
        display: none;
    }
}
/* MOBILE MENU SYSTEM */




.pagination {
	margin: 5px 0px;
}

#pm {
	background-color: #f5f5f5;
	width: 35px;
	height: 20px;
	position: absolute;
	right: 0;
	bottom: 79px;
	border-left: 1px solid black;
	border-top: 1px solid black;
	border-top-left-radius: 5px;
	.box {
		margin-left: 3px;
	}
	.box:hover {
		background-color: lightgray;
	}
}

.message-box {
	z-index: 50;
	background-color: #f5f5f5;
	height: 275px;
	width: 225px;
	position: relative;
	top: -38px;
	float: right;
	margin-left: 5px;
	transition: top .5s;
	.title-bar {
		background-color: #404040;
		height: 38px;
		cursor: pointer;
		.type {
			i {
				color: white;
				font-size: 178%;
				top: 5px;
				position: absolute;
				left: 7px;
			}
		}
		.name {
			color: white;
			vertical-align: middle;
			top: 0px;
			position: relative;
			left: 39px;
			display: inline-block;
			font-size: 12px;
			white-space: nowrap;
			overflow: hidden;
			width: 127px;
			line-height: 1.5;
			font-weight: bold;
			margin-top: 2px;
			.from {
				display: inline-block;
			}
			.to {
				display: inline-block;
			}
		}
		.actions {
			position: absolute;
			right: 3px;
			top: 4px;
			i {
				color: white;
				font-size: 136%;
				float: right;
				padding: 5px;
				border: 1px solid transparent;
			}
			i:hover {
				background-color: lightgray;
				color: black;
				border: 1px solid black;
			}
		}
	}
	.window {
		/* Fix for Scroll bars showing in Chrome */
		-webkit-transform: translate3d(0, 0, 0);
		/* end fix */
		border-left: 1px solid black;
		border-right: 1px solid black;
		height: 237px;
		font-family: 'lato';
		.chat {
			height: 183px;
			overflow-x: hidden;
			overflow-y: auto;
			padding: 5px;
			font-size: 13px;
			line-height: 1.3;
			.history {
				.message {
					opacity: 0.7;
					transition: opacity .25s ease-in-out;
				}
				.message:hover {
					opacity: 1;
				}
			}
			.message {
				padding: 4px 9px 4px 9px;
				margin-bottom: 2px;
				border-radius: 11px;
				min-height: 24px;
			}
			.message.in {
				text-align: left;
				left: 0px;
				position: relative;
				background-color: #e0e0e0;
				color: black;
				a {
					color: black;
				}
			}
			.message.in:after {
				content: "";
				position: absolute;
				bottom: 1px;
				left: -5px;
				border-style: solid;
				border-width: 7px 15px 3px 0;
				border-color: transparent #e0e0e0;
				display: block;
				width: 0;
				z-index: -2;
			}
			.message.out {
				text-align: right;
				right: 0px;
				position: relative;
				background-color: #3b8cd2;
				color: white;
				a {
					color: white;
				}
			}
			.message.out:after {
				content: "";
				position: absolute;
				bottom: 1px;
				right: -5px;
				border-style: solid;
				border-width: 3px 0px 7px 15px;
				border-color: transparent #3b8cd2;
				display: block;
				width: 0;
				z-index: -2;
			}
			.status {
				text-align: center;
				color: gray;
				font-size: 11px;
				font-style: italic;
			}
		}
		.response-status {
			text-align: center;
			color: gray;
			font-size: 11px;
			font-style: italic;
			height: 15px;
			margin-bottom: -7px;
		}
		.response {
			textarea {
				height: 36px;
				resize: none;
				width: 90%;
				margin-left: 11px;
				margin-top: 5px;
				font-size: 85%;
				line-height: 1;
			}
		}
	}
}

.message-box.expand {
	top: -275px;
}

.phone-box {
	z-index: 50;
	background-color: #f5f5f5;
	height: 315px;
	width: 225px;
	position: relative;
	top: -38px;
	float: right;
	margin-left: 5px;
	transition: top .5s;
	.title-bar {
		background-color: #404040;
		height: 38px;
		cursor: pointer;
		.type {
			i {
				color: white;
				font-size: 178%;
				top: 7px;
				position: absolute;
				left: 7px;
			}
		}
		.name {
			color: white;
			vertical-align: middle;
			top: 0px;
			position: relative;
			left: 32px;
			display: inline-block;
			font-size: 103%;
			white-space: nowrap;
			overflow: hidden;
			width: 133px;
			.message-container {
				text-align: center;
				width:133px;
				height:17px;
				.message {

				}
			}
			.title {
				text-align: center;
			}
		}
		.actions {
			position: absolute;
			right: 3px;
			top: 4px;
			i {
				color: white;
				font-size: 136%;
				float: right;
				padding: 5px;
				border: 1px solid transparent;
			}
			i:hover {
				background-color: lightgray;
				color: black;
				border: 1px solid black;
			}
		}
	}
	.window {
		/* Fix for Scroll bars showing in Chrome */
		-webkit-transform: translate3d(0, 0, 0);
		/* end fix */
		border-left: 1px solid black;
		border-right: 1px solid black;
		height: 278px;
		font-family: 'lato';
		table.keypad {
			margin: auto;
			position: relative;
			top: 7px;
			table-layout: fixed;
			td {
				cursor: pointer;
				border: 1px solid rgb(201, 201, 201);
				width: 64px;
				height: 43px;
				text-align: center;
				border-radius: 0px;
				.num {
					font-weight: bold;
				}
				.letters {
					font-size: 86%;
					color: rgb(172, 172, 172);
					margin-top: -4px;
				}
			}
			td.upper-left {
				border-top-left-radius: 4px;
			}
			td.upper-right {
				border-top-right-radius: 4px;
			}
			td.lower-left {
				border-bottom-left-radius: 4px;
			}
			td.lower-right {
				border-bottom-right-radius: 4px;
			}
		}
		.activeCallSession {
			position: relative;
			top: 6px;
			width: 100%;
			height: 217px;
		}
		.contactDisplay {
			display: none;
			position: absolute;
			width: 99%;
			height: 230px;
			z-index: 50;
			background-color: #f5f5f5;
			padding-left: 17px;
			padding-right: 17px;
			padding-top: 7px;
			.contactImage {
				border: 1px solid rgb(187, 187, 187);
				/* TODO: this is wrong */
				background-image: url('/ucp/modules/Webrtc/assets/images/no_user_logo.png');
				background-position: center;
				height: 163px;
				border: 1px solid rgb(187, 187, 187);
				background-size: contain;
				background-repeat: no-repeat;
				position: relative;
				top: 9px;
			}
			.contactInfo {
				position: relative;
				top: 17px;
				text-align: center;
				width: 189px;
				height: 39px;
				span {
					font-weight: bold;
				}
			}

		}
		.input-container {
			width: 191px;
			top: 3px;
			position: relative;
			left: 16px;
		}
		.actions {
			position: absolute;
			bottom: 8px;
			left: 16px;
			width: 192px;
			table-layout: fixed;
			td {
				padding-left: 1px;
				padding-right: 1px;
				.right {
					display: none;
				}
			}
			button.action {
				width: 100%;
			}
			button.secondaction {
				width: 100%;
			}
		}
	}
}

.phone-box.expand {
	top: -315px;
}

#ucp-settings {
	.password-set {
		border: 1px solid #CCCCCC;
		padding: 6px;
		border-radius: 5px;
		margin-bottom: 8px;
		legend {
			margin-bottom: 3px;
		}
	}
	.vmsettings {
		background-color: aliceblue;
		border-radius: 10px;
		padding: 10px;
		width: 370px;
		@media only screen and (max-width : 991px) {
			width: 100%;
		}
	}
}

#loading-container {
	background-color: rgba(211, 211, 211, 0.2);
	position: absolute;
	height: 100%;
	width: 100%;
	z-index: 9999;
	.message-container {
		position: fixed;
		top: 50%;
		left: 44%;
		.message {
			background-color: #f5f5f5;
			width: 200px;
			text-align: center;
			padding: 15px;
			border-radius: 10px;
			border: 1px solid lightgrey;
			box-shadow: 4px 4px 9px rgba(136, 136, 136, 0.42);
		}
	}
}

select[multiple].Tokenize, select[size].Tokenize {
	color: #ffffff;
	background-color: #ffffff;
	height: 34px;
	margin-bottom: 4px;
}

.bootstrap-table {
	.fixed-table-toolbar {
		.dropdown-menu {
			right: 0px;
			left: inherit;
			padding: 4px;
		}
	}
	.card-view {
		.title {
			font-weight: bold;
			margin-right: 2px;
		}
	}
	tr {
		color: black;
		background-color: rgba(255, 255, 255, 0.5);
	}
	tr:hover {
		background-color: #f5f5f5;
	}
	.sortable {
		cursor: pointer;
	}
	td {
		a {
			color: #337ab7;
			text-decoration: none;
			cursor: pointer;
			margin-right: 5px;
			i {
				font-size: large;
			}
		}
		a:last-of-type {
			margin-right: 0px;
		}
	}
}

.bootstrap-table {
	thead tr {
		background-color: #f5f5f5;
	}
	.fixed-table-loading {
		z-index: 1199;
		background-color: #EEF6FF;
		opacity: 0.95;
		font-weight: bold;
	}
}

.clickable {
	color: #428bca;
	text-decoration: none;
	cursor: pointer;
}
.clickable:hover {
	text-decoration: underline;
}

#ucp-settings {
	.settings {
		background-color: aliceblue;
		border-radius: 10px;
		.title {
			padding: 5px;
			font-weight: bold;
			text-align: center;
			background-color: whitesmoke;
			border-top-left-radius: 5px;
			border-top-right-radius: 5px;
		}
		.content {
			padding: 10px;
		}
	}
	.section {
		margin-bottom: 10px;
		width: 33.3%
	}

	#contactmanager_dropzone {
		min-height: 75px;
		width: 90px;
		border: 3px dotted #ccc;
		background-color: #F5F5F5;
		border-radius: 10px;
		margin-top: 0px;
		margin-bottom: 3px;
	}
	#contactmanager_dropzone .message {
		text-align: center;
		font-weight: bold;
		font-size: 86%;
		margin-left: 2px;
	}
	#contactmanager_dropzone.image img{
		width: 100%;
	}
	#contactmanager_upload-progress {
		margin-top: 5px;
		margin-bottom: 0px;
	}
	#contactmanager_dropzone.activate {
		border-color: black;
	}

	#contactmanager_dropzone.activate .message {
		opacity: .5;
	}
}
