/*Transition*/
.pushmenu, .pushmenu-push {
	@media only screen and (max-width : 767px) {
        -webkit-transition: all 0.3s ease;
        -moz-transition: all 0.3s ease;
        transition: all 0.3s ease;
	}
}

.pushmenu {
        background: #3c3933;
        font-family: Arial, Helvetica, sans-serif;
        position: fixed;
        width: 205px;
        height: 100%;
        top: 0;
        z-index: 1000;
		overflow-y: auto; //scrolling long menus on devices
}

.pushmenu h3 {
        color: #cbbfad;
        font-size: 14px;
        font-weight: bold;
        padding: 15px 20px;
        margin: 0;
        background: #282522;
        height: 16px;
}
/*
.pushmenu a {
        display: block;
        color: #fff;
        font-size: 16px;
        font-weight: bold;
        text-decoration: none;
        border-top: 1px solid #57544e;
        border-bottom: 1px solid #312e2a;
        padding: 14px;
}

.pushmenu a:hover {
        background:258ecd;
}

.pushmenu a:active {
        background: #454f5c;
        color: #fff;
}
*/

.pushmenu .active {
        background: black;
}

.pushmenu a {
	display: block;
    color: #fff;
    text-decoration: none;
	padding: 14px;
	cursor: pointer;
}

.pushmenu li {
    display: block;
    color: #fff;
    font-size: 16px;
    font-weight: bold;
    text-decoration: none;
    border-top: 1px solid #57544e;
    border-bottom: 1px solid #312e2a;
    padding: 0px;
	overflow-x: hidden;
	white-space: nowrap;
}

.pushmenu ul {
	padding-left: 0px;
}

.pushmenu li.active {
        background: black;
}

.pushmenu .dropdown-pushmenu {
	display: none;
	background-color: #5F5A50;
    border-top: 1px solid #57544e;
    border-bottom: 1px solid #312e2a;
}

.pushmenu .dropdown-pushmenu a{
	font-size: 85%;
	padding-left: 30px;
}

.pushmenu-left {
        left: -205px;
}

.pushmenu-left.pushmenu-open {
        left: 0px;
}

.pushmenu-push {
		overflow-x: hidden;
		@media only screen and (max-width : 767px) {
			position: relative;
		}
		left: 0;
}

.pushmenu-push-toright {
        left: 205px;
		position: fixed;
}
