@button-color: #d7ebf9;
.button-border(@color) {
	border: 1px solid @color;
}
.button-layout() {
	.button-border(#aed0ea);
	background: @button-color url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAGQEAIAAACwqkHPAAAABmJLR0T///////8JWPfcAAAACXBIWXMAAABIAAAASABGyWs+AAAAmElEQVRIx+3PIQ6CABgF4PfeZnPTanBjGjUYNBPkEGwmvREHMDhOQDI7PAEFNzHoHAYcQRJI8BROw5++/OEevfx3LgAADMMwjG+DNC2KusbJf06brjhCgKm45A4zZE7Za7a4xOW1yaSQCV3pyCs8MeYNnhQygYt8Xg1aB499dW5X0oYRFuKYASbCAWsMRQd9dP4ibRiG8UM+QjMuTsD8TMoAAAAldEVYdGRhdGU6Y3JlYXRlADIwMTMtMDUtMDNUMDk6MjE6MTgtMDc6MDDQs4aNAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDEzLTA1LTAzVDA5OjIxOjE4LTA3OjAwoe4+MQAAAABJRU5ErkJggg==) 50% 50% repeat-x;
	color: #2779aa;
	font-family: Lucida Grande,Lucida Sans,Arial,sans-serif;
	display: inline-block;
	position: relative;
	line-height: normal;
	margin-right: .1em;
	cursor: pointer;
	vertical-align: middle;
	text-align: center;
	overflow: visible;
	font-size: 11px !important;
	padding: .4em 1em;
	font-weight: bold;
}

.button-hover() {
	.button-border(#74b2e2);
	background: @button-color url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAGQEAIAAACwqkHPAAAABmJLR0T///////8JWPfcAAAACXBIWXMAAABIAAAASABGyWs+AAAAnElEQVRIx+3PrQrCYBiG4ed50SSIUbC6MLa4ZNFiMC6sCnoinoGYLIs7iBWTxeBhOJN/fIP9wPaBwWMQDW+62g03XodqZ/cCAICiKIrybZBlxjQNrmHutj1hgQ3GwgG3cIUeYvjCNVMEuM2LWfvA/Vh2rYPntDzbpXDFFAGM1BN7Qr6oL7YSeozpf2KOMGGEoWCEPjp/Ma0oivJD3kmDL+OlYr6CAAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDEzLTA1LTAzVDA5OjIxOjE4LTA3OjAw0LOGjQAAACV0RVh0ZGF0ZTptb2RpZnkAMjAxMy0wNS0wM1QwOToyMToxOC0wNzowMKHuPjEAAAAASUVORK5CYII=) 50% 50% repeat-x;
	color: #0070a3;
}

.button-active() {
	.button-border(#2694e8);
	background: @button-color url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAGQEAIAAACwqkHPAAAABmJLR0T///////8JWPfcAAAACXBIWXMAAABIAAAASABGyWs+AAAAjklEQVRIx2NImrp798smJgYGBgYGhlFqlBqlRqlRiubUzWXv3/9KZGLsZlzNaMHEUsnYxFDPxHKHaQ1jHxOLHdN1htlMrCxMuozbIdQOJtZ05giGo0xs6UzhjMfQ5FgWMjExrGRitWO6zjibobj/sMTr90xMgYyMjKFMjMkM2gx8g8PTo9QoNUqNUgNHAQAy4iFUVISQBwAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAxMy0wNS0wM1QwOToyMToxOC0wNzowMNCzho0AAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTMtMDUtMDNUMDk6MjE6MTgtMDc6MDCh7j4xAAAAAElFTkSuQmCC) 50% 50% repeat-x;
	color: #ffffff;
}

.button-disabled() {
	opacity: .35;
	filter: Alpha(Opacity=35);
	background-image: none;
	cursor: default;
}

/* BUTTON CSS */
.btn, button, input[type="button"], input[type="reset"], input[type="submit"] {
	.button-layout();
	border-radius: 6px;
}
.btn:hover, button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover{
	.button-hover();
}
.btn:focus, button:focus, input[type="button"]:focus, input[type="reset"]:focus, input[type="submit"]:focus{
	.button-hover();
}
.btn:active, button:active, input[type="button"]:active, input[type="reset"]:active, input[type="submit"]:active{
	.button-active();
}
.btn:disabled, button:disabled, input[type="button"]:disabled, input[type="reset"]:disabled, input[type="submit"]:disabled{
	.button-disabled();
}

/* RADIOSET/CHECKSET */
.radioset input[type="radio"], .checkset input[type="checkbox"] {
	display:none;
}
.radioset input[type="radio"] + label, .checkset input[type="checkbox"] ~ label {
	.button-layout();
	margin-right: -3px;
}
.radioset input[type="radio"] + label:first-of-type, .checkset input[type="checkbox"] ~ label:first-of-type {
	border-top-left-radius: 6px;
	border-bottom-left-radius: 6px;
}
.radioset input[type="radio"] + label:last-of-type, .checkset input[type="checkbox"] ~ label:last-of-type {
	border-top-right-radius: 6px;
	border-bottom-right-radius: 6px;
}
.radioset input[type="radio"] + label:hover, .checkset input[type="checkbox"] ~ label:hover {
	.button-hover();
}
.radioset input[type="radio"]:checked + label, .checkset input[type="checkbox"]:checked + label {
	.button-active();
}

.radioset input[type="radio"]:disabled + label, .checkset input[type="checkbox"]:disabled + label {
	.button-disabled();
}
