/* FONT PATH
 * -------------------------- */

@font-face {
  font-family: 'Schmooze';
  src: url('@{sf-font-path}/Schmooze.eot?v=@{sf-version}');
  src: url('@{sf-font-path}/Schmooze.eot?#iefix&v=@{sf-version}') format('embedded-opentype'),
    url('@{sf-font-path}/Schmooze.woff?v=@{sf-version}') format('woff'),
    url('@{sf-font-path}/Schmooze.ttf?v=@{sf-version}') format('truetype'),
    url('@{sf-font-path}/Schmooze.svg?v=@{sf-version}#3af32675a7ac9cab7dcf32a92eb65396') format('svg');
  font-weight: normal;
  font-style: normal;
}
